<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>MFPlayerSession</name>
    <message>
        <source>Invalid stream source.</source>
        <translation>Ungültige Datenstromquelle.</translation>
    </message>
    <message>
        <source>Attempting to play invalid Qt resource.</source>
        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen.</translation>
    </message>
    <message>
        <source>The system cannot find the file specified.</source>
        <translation>Das System kann die angegebene Datei nicht finden.</translation>
    </message>
    <message>
        <source>The specified server could not be found.</source>
        <translation>Der angegebene Server konnte nicht gefunden werden.</translation>
    </message>
    <message>
        <source>Unsupported media type.</source>
        <translation>Nicht unterstützter Medientyp.</translation>
    </message>
    <message>
        <source>Unsupported URL scheme.</source>
        <translation>Nicht unterstütztes URL-Schema.</translation>
    </message>
    <message>
        <source>Connection to server could not be established.</source>
        <translation>Verbindung zum Server konnte nicht hergestellt werden.</translation>
    </message>
    <message>
        <source>Failed to load source.</source>
        <translation>Die Quelle konnte nicht geladen werden.</translation>
    </message>
    <message>
        <source>Cannot create presentation descriptor.</source>
        <translation>Der Präsentationsdeskriptor kann nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Failed to get stream count.</source>
        <translation>Anzahl der Datenströme konnte nicht bestimmt werden.</translation>
    </message>
    <message>
        <source>Failed to create topology.</source>
        <translation>Topologie konnte nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Unable to play any stream.</source>
        <translation>Es konnte kein Datenstrom abgespielt werden.</translation>
    </message>
    <message>
        <source>Unable to play.</source>
        <translation>Abspielen nicht möglich.</translation>
    </message>
    <message>
        <source>Failed to set topology.</source>
        <translation>Topologie konnte nicht gesetzt werden.</translation>
    </message>
    <message>
        <source>Unknown stream type.</source>
        <translation>Unbekannter Datenstromtyp.</translation>
    </message>
    <message>
        <source>Failed to stop.</source>
        <translation>Stoppen nicht möglich.</translation>
    </message>
    <message>
        <source>Failed to pause.</source>
        <translation>Pausieren nicht möglich.</translation>
    </message>
    <message>
        <source>Unable to create mediasession.</source>
        <translation>Es konnte keine Medien-Session erzeugt werden.</translation>
    </message>
    <message>
        <source>Unable to pull session events.</source>
        <translation>Events der Sitzung konnten nicht abgeholt werden.</translation>
    </message>
    <message>
        <source>Failed to seek.</source>
        <translation>Positionierung fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Media session non-fatal error.</source>
        <translation>Unkritischer Fehler der Medien-Session.</translation>
    </message>
    <message>
        <source>Error reading from the network.</source>
        <translation>Fehler beim Lesen vom Netzwerk.</translation>
    </message>
    <message>
        <source>Error writing to the network.</source>
        <translation>Fehler beim Schreiben zum Netzwerk.</translation>
    </message>
    <message>
        <source>Network packets might be blocked by a firewall.</source>
        <translation>Netzwerkpakete könnten durch eine Firewall blockiert werden.</translation>
    </message>
    <message>
        <source>Media session state error.</source>
        <translation>Fehlerhafter Status der Medien-Session.</translation>
    </message>
    <message>
        <source>Invalid stream data.</source>
        <translation>Ungültige Daten aus Datenstrom.</translation>
    </message>
    <message>
        <source>Media session serious error.</source>
        <translation>Kritischer Fehler der Medien-Session.</translation>
    </message>
    <message>
        <source>Unsupported media, a codec is missing.</source>
        <translation>Nicht unterstütztes Medium; es fehlt ein Codec.</translation>
    </message>
    <message>
        <source>failed to start playback</source>
        <translation>Playback konnte nicht gestartet werden</translation>
    </message>
</context>
<context>
    <name>QAndroidCameraSession</name>
    <message>
        <source>Failed to capture image</source>
        <translation>Es konnte kein Bild aufgenommen werden</translation>
    </message>
    <message>
        <source>Camera preview failed to start.</source>
        <translation>Die Kamera-Vorschau konnte nicht gestartet werden.</translation>
    </message>
    <message>
        <source>File is not available: %1</source>
        <translation>Die Datei ist nicht verfügbar: %1</translation>
    </message>
    <message>
        <source>Could not save to file: %1</source>
        <translation>Konnte nicht in Datei speichern: %1</translation>
    </message>
</context>
<context>
    <name>QAudioDecoder</name>
    <message>
        <source>QAudioDecoder not supported.</source>
        <translation>QAudioDecoder wird nicht unterstützt.</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen</translation>
    </message>
    <message>
        <source>Failed to establish temporary file during playback</source>
        <translation>Es konnte keine temporäre Datei während des Abspielens erstellt werden</translation>
    </message>
    <message>
        <source>Could not open file</source>
        <translation>Die Datei konnte nicht geöffnet werden</translation>
    </message>
    <message>
        <source>Could not find stream information for media file</source>
        <translation>Es konnten keine Stream-Informationen zur Mediendatei gefunden werden</translation>
    </message>
</context>
<context>
    <name>QImageCapture</name>
    <message>
        <source>Camera is not ready.</source>
        <translation>Kamera nicht bereit.</translation>
    </message>
    <message>
        <source>Could not capture in stopped state</source>
        <translation>Im Stopp-Zustand kann nicht aufgenommen werden</translation>
    </message>
    <message>
        <source>No instance of QImageCapture set on QMediaCaptureSession.</source>
        <translation>Es ist keine Instanz von QImageCapture in QMediaCaptureSession gesetzt.</translation>
    </message>
</context>
<context>
    <name>AVFAudioDecoder</name>
    <message>
        <source>Unable to read from specified device</source>
        <translation>Vom angegebenen Gerät kann nicht gelesen werden</translation>
    </message>
    <message>
        <source>Could not load media source&apos;s tracks</source>
        <translation>Die Medienspuren konnten nicht geladen werden</translation>
    </message>
    <message>
        <source>Unsupported source format</source>
        <translation>Nicht unterstütztes Quellformat</translation>
    </message>
    <message>
        <source>Failed to add asset reader output</source>
        <translation>Die Ausgabe des Asset-Lesers konnte nicht hinzugefügt werden</translation>
    </message>
    <message>
        <source>Could not start reading</source>
        <translation>Lesevorgang konnte nicht gestartet werden</translation>
    </message>
</context>
<context>
    <name>AVFCameraSession</name>
    <message>
        <source>Runtime camera error</source>
        <translation>Laufzeit-Kamerafehler</translation>
    </message>
</context>
<context>
    <name>AVFImageCapture</name>
    <message>
        <source>Could not open destination file:
%1</source>
        <translation>Die Zieldatei konnte nicht geöffnet werden:
%1</translation>
    </message>
</context>
<context>
    <name>AVFMediaEncoder</name>
    <message>
        <source>No inputs specified</source>
        <translation>Es wurden keine Eingänge angegeben</translation>
    </message>
    <message>
        <source>Invalid output file URL</source>
        <translation>Ungültiger URL zur Ausgabedatei</translation>
    </message>
    <message>
        <source>Non-writeable file location</source>
        <translation>Datei ist nicht schreibbar</translation>
    </message>
    <message>
        <source>File already exists</source>
        <translation>Datei existiert bereits</translation>
    </message>
</context>
<context>
    <name>AVFMediaPlayer</name>
    <message>
        <source>Failed to load media</source>
        <translation>Medien konnten nicht geladen werden</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioDecoder</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Datenstrom des Typs &lt;unbekannt&gt; kann nicht abgespielt werden</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageCapture</name>
    <message>
        <source>No camera available.</source>
        <translation>Es ist keine Kamera verfügbar.</translation>
    </message>
</context>
<context>
    <name>QWindowsMediaEncoder</name>
    <message>
        <source>Failed to resume recording</source>
        <translation>Aufnahme konnte nicht fortgesetzt werden</translation>
    </message>
    <message>
        <source>Failed to pause recording</source>
        <translation>Aufnahme konnte nicht angehalten werden</translation>
    </message>
    <message>
        <source>Camera is no longer present</source>
        <translation>Kamera ist nicht mehr vorhanden</translation>
    </message>
    <message>
        <source>Streaming error</source>
        <translation>Streaming-Fehler</translation>
    </message>
    <message>
        <source>Audio input is no longer present</source>
        <translation>Audioeingabe ist nicht mehr vorhanden</translation>
    </message>
    <message>
        <source>Recording error</source>
        <translation>Aufnahmefehler</translation>
    </message>
</context>
<context>
    <name>QMediaRecorder</name>
    <message>
        <source>Failed to start recording</source>
        <translation>Aufnahme konnte nicht gestartet werden</translation>
    </message>
    <message>
        <source>Pause not supported</source>
        <translation>Pausieren wird nicht unterstützt</translation>
    </message>
    <message>
        <source>Resume not supported</source>
        <translation>Fortsetzen wird nicht unterstützt</translation>
    </message>
    <message>
        <source>No camera or audio input</source>
        <translation>Kein Kamera- oder kein Audiosignal</translation>
    </message>
    <message>
        <source>No video or audio input</source>
        <translation>Kein Video- oder Audiosignal</translation>
    </message>
    <message>
        <source>Cannot open the output location for writing</source>
        <translation>Das Ausgabeziel kann nicht zum Schreiben geöffnet werden</translation>
    </message>
</context>
<context>
    <name>QMediaMetaData</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Publisher</source>
        <translation>Herausgeber</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Urheberrecht</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <source>Media type</source>
        <translation>Medientyp</translation>
    </message>
    <message>
        <source>Container Format</source>
        <translation>Container-Format</translation>
    </message>
    <message>
        <source>Audio bit rate</source>
        <translation>Audio-Bitrate</translation>
    </message>
    <message>
        <source>Audio codec</source>
        <translation>Audio-Codec</translation>
    </message>
    <message>
        <source>Video bit rate</source>
        <translation>Video-Bitrate</translation>
    </message>
    <message>
        <source>Video codec</source>
        <translation>Video-Codec</translation>
    </message>
    <message>
        <source>Video frame rate</source>
        <translation>Bildrate</translation>
    </message>
    <message>
        <source>Album title</source>
        <translation>Albumtitel</translation>
    </message>
    <message>
        <source>Album artist</source>
        <translation>Künstler</translation>
    </message>
    <message>
        <source>Contributing artist</source>
        <translation>Beteiligte Künstler</translation>
    </message>
    <message>
        <source>Track number</source>
        <translation>Titelnummer</translation>
    </message>
    <message>
        <source>Composer</source>
        <translation>Komponist</translation>
    </message>
    <message>
        <source>Thumbnail image</source>
        <translation>Vorschaubild</translation>
    </message>
    <message>
        <source>Cover art image</source>
        <translation>Albumcover</translation>
    </message>
    <message>
        <source>Orientation</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <source>Lead performer</source>
        <translation>Hauptinterpret</translation>
    </message>
    <message>
        <source>Has HDR content</source>
        <translation>Hat HDR-Inhalt</translation>
    </message>
</context>
<context>
    <name>Decoder</name>
    <message>
        <source>Cannot set source, invalid mime type for the source provided.</source>
        <translation>Es kann keine Quelle eingestellt werden; die angegebene Quelle hat einen ungültigen MIME-Typ.</translation>
    </message>
    <message>
        <source>Cannot open the file</source>
        <translation>Datei kann nicht geöffnet werden</translation>
    </message>
    <message>
        <source>Invalid fileDescriptor for source.</source>
        <translation>Ungültiger Dateideskriptor der Quelle.</translation>
    </message>
    <message>
        <source>Setting source for Audio Decoder failed.</source>
        <translation>Das Setzen der Quelle des Audio-Decoders schlug fehl.</translation>
    </message>
    <message>
        <source>Format not supported by Audio Decoder.</source>
        <translation>Das Format wird vom Audio-Decoder nicht unterstützt.</translation>
    </message>
    <message>
        <source>Cannot decode, source not set.</source>
        <translation>Dekodieren nicht möglich, keine Quelle gesetzt.</translation>
    </message>
    <message>
        <source>Audio Decoder could not be created.</source>
        <translation>Audio-Decoder konnte nicht erstellt werden.</translation>
    </message>
    <message>
        <source>Audio Decoder failed configuration.</source>
        <translation>Konfiguration des Audio-Decoders schlug fehl.</translation>
    </message>
    <message>
        <source>Audio Decoder failed to start.</source>
        <translation>Audio-Decoder konnte nicht gestartet werden.</translation>
    </message>
</context>
<context>
    <name>MFAudioDecoderControl</name>
    <message>
        <source>Unsupported media type</source>
        <translation>Nicht unterstützter Medientyp</translation>
    </message>
    <message>
        <source>Media not found</source>
        <translation>Medium nicht gefunden</translation>
    </message>
    <message>
        <source>Unable to load specified URL</source>
        <translation>Die angegebene URL konnte nicht geladen werden</translation>
    </message>
    <message>
        <source>Could not instantiate MFDecoderSourceReader</source>
        <translation>MFDecoderSourceReader konnte nicht instanziiert werden</translation>
    </message>
    <message>
        <source>Invalid media format</source>
        <translation>Ungültiges Medienformat</translation>
    </message>
    <message>
        <source>Unable to read from specified device</source>
        <translation>Vom angegebenen Gerät kann nicht gelesen werden</translation>
    </message>
    <message>
        <source>No media source specified</source>
        <translation>Es wurden keine Medienquelle angegeben</translation>
    </message>
    <message>
        <source>Failed processing a sample</source>
        <translation>Aufnahme konnte nicht verarbeitet werden</translation>
    </message>
</context>
<context>
    <name>QAndroidAudioDecoder</name>
    <message>
        <source>Error opening temporary file: %1</source>
        <translation>Fehler beim Öffnen der temporären Datei: %1</translation>
    </message>
    <message>
        <source>Error while writing data to temporary file</source>
        <translation>Fehler beim Schreiben der temporären Datei</translation>
    </message>
</context>
</TS>
